note 23524 deleted from function.imagecopyresampled by aidan

From: Date: Mon, 04 Oct 2004 09:45:04 +0000
Subject: note 23524 deleted from function.imagecopyresampled by aidan
References: 1  Groups: php.notes 
Request: Send a blank email to php-notes+get-77965@lists.php.net to get a copy of this message
Note Submitter: mdreed at mac dot com ---- In my experience, imagecopyresampled is _much_ slower than imagecopyresized. In a sample 200kb 1024x768 true color JPEG, it took 6.76 seconds to resample it to 800x600, while it took only 0.50 seconds to resize it to the same resolution. Resizing, however, left the picture with a jagged quality, unacceptable in most applications.

« previous php.notes (#77965) next »